@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -23,10 +23,6 @@
 #include "mapping.h"
 #include "sort.h"
 #include "mailbox.h"
-#include "browser.h"
-#ifdef USE_IMAP
-#include "imap.h"
-#endif
 
 #include <stdlib.h>
 #include <dirent.h>
@@ -37,6 +33,22 @@
 #include <pwd.h>
 #include <grp.h>
 
+struct folder_file
+{
+  mode_t mode;
+  time_t mtime;
+  off_t size;
+  char *name;
+  char *desc;
+};
+
+struct browser_state
+{
+  struct folder_file *entry;
+  short entrylen; /* number of real entries */
+  short entrymax;  /* max entry */
+};
+
 static struct mapping_t FolderHelp[] = {
   { N_("Exit"),  OP_EXIT },
   { N_("Chdir"), OP_CHANGE_DIRECTORY },
@@ -47,8 +59,9 @@ static struct mapping_t FolderHelp[] = {
 
 typedef struct folder_t
 {
-  struct folder_file *ff;
-  int num;
+  const char *name;
+  const struct stat *f;
+  int new;
 } FOLDER;
 
 static char LastDir[_POSIX_PATH_MAX] = "";
@@ -62,11 +75,7 @@ static void destroy_state (struct browser_state *state)
   {
     safe_free ((void **) &((state->entry)[c].name));
     safe_free ((void **) &((state->entry)[c].desc));
-    safe_free ((void **) &((state->entry)[c].st));
   }
-#ifdef USE_IMAP
-  safe_free ((void **) &state->folder);
-#endif
   safe_free ((void **) &state->entry);
 }
 
@@ -146,17 +155,12 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 
   switch (op)
   {
-    case 'C':
-      snprintf (tmp, sizeof (tmp), "%%%sd", fmt);
-      snprintf (dest, destlen, tmp, folder->num + 1);
-      break;
-      
     case 'd':
-      if (folder->ff->st != NULL)
+      if (folder->f != NULL)
       {
 	tnow = time (NULL);
-	t_fmt = tnow - folder->ff->st->st_mtime < 31536000 ? "%b %d %H:%M" : "%b %d  %Y";
-	strftime (date, sizeof (date), t_fmt, localtime (&folder->ff->st->st_mtime));
+	t_fmt = tnow - folder->f->st_mtime < 31536000 ? "%b %d %H:%M" : "%b %d  %Y";
+	strftime (date, sizeof (date), t_fmt, localtime (&folder->f->st_mtime));
 	snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
 	snprintf (dest, destlen, tmp, date);
       }
@@ -166,57 +170,49 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	snprintf (dest, destlen, tmp, "");
       }
       break;
-      
     case 'f':
-#ifdef USE_IMAP
-      if (mx_is_imap (folder->ff->name))
-        strfcpy (fn, NONULL(folder->ff->desc), sizeof (fn));
-      else
-#endif
-      strfcpy (fn, folder->ff->name, sizeof(fn));
-      if (folder->ff->st != NULL)
+      strfcpy (fn, folder->name, sizeof(fn));
+      if (folder->f != NULL)
       {
-	strcat (fn, S_ISLNK (folder->ff->st->st_mode) ? "@" : 
-		(S_ISDIR (folder->ff->st->st_mode) ? "/" : 
-		 ((folder->ff->st->st_mode & S_IXUSR) != 0 ? "*" : "")));
+	strcat (fn, S_ISLNK (folder->f->st_mode) ? "@" : 
+		(S_ISDIR (folder->f->st_mode) ? "/" : 
+		 ((folder->f->st_mode & S_IXUSR) != 0 ? "*" : "")));
       }
       snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
       snprintf (dest, destlen, tmp, fn);
       break;
-      
     case 'F':
-      if (folder->ff->st != NULL)
+      if (folder->f != NULL)
       {
 	sprintf (permission, "%c%c%c%c%c%c%c%c%c%c",
-	    S_ISDIR(folder->ff->st->st_mode) ? 'd' : (S_ISLNK(folder->ff->st->st_mode) ? 'l' : '-'),
-	    (folder->ff->st->st_mode & S_IRUSR) != 0 ? 'r': '-',
-	    (folder->ff->st->st_mode & S_IWUSR) != 0 ? 'w' : '-',
-	    (folder->ff->st->st_mode & S_ISUID) != 0 ? 's' : (folder->ff->st->st_mode & S_IXUSR) != 0 ? 'x': '-',
-	    (folder->ff->st->st_mode & S_IRGRP) != 0 ? 'r' : '-',
-	    (folder->ff->st->st_mode & S_IWGRP) != 0 ? 'w' : '-',
-	    (folder->ff->st->st_mode & S_ISGID) != 0 ? 's' : (folder->ff->st->st_mode & S_IXGRP) != 0 ? 'x': '-',
-	    (folder->ff->st->st_mode & S_IROTH) != 0 ? 'r' : '-',
-	    (folder->ff->st->st_mode & S_IWOTH) != 0 ? 'w' : '-',
-	    (folder->ff->st->st_mode & S_ISVTX) != 0 ? 't' : (folder->ff->st->st_mode & S_IXOTH) != 0 ? 'x': '-');
+		 S_ISDIR(folder->f->st_mode) ? 'd' : (S_ISLNK(folder->f->st_mode) ? 'l' : '-'),
+		 (folder->f->st_mode & S_IRUSR) != 0 ? 'r': '-',
+		 (folder->f->st_mode & S_IWUSR) != 0 ? 'w' : '-',
+		 (folder->f->st_mode & S_ISUID) != 0 ? 's' : (folder->f->st_mode & S_IXUSR) != 0 ? 'x': '-',
+		 (folder->f->st_mode & S_IRGRP) != 0 ? 'r' : '-',
+		 (folder->f->st_mode & S_IWGRP) != 0 ? 'w' : '-',
+		 (folder->f->st_mode & S_ISGID) != 0 ? 's' : (folder->f->st_mode & S_IXGRP) != 0 ? 'x': '-',
+		 (folder->f->st_mode & S_IROTH) != 0 ? 'r' : '-',
+		 (folder->f->st_mode & S_IWOTH) != 0 ? 'w' : '-',
+		 (folder->f->st_mode & S_ISVTX) != 0 ? 't' : (folder->f->st_mode & S_IXOTH) != 0 ? 'x': '-');
 	snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
 	snprintf (dest, destlen, tmp, permission);
       }
       else
       {
 #ifdef USE_IMAP
-	if (mx_is_imap (folder->ff->name))
+	if (strchr(folder->name, '{'))
 	{
-          snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
-          snprintf (dest, destlen, tmp, "IMAP");
+	  snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
+	  snprintf (dest, destlen, tmp, "IMAP");
 	}                                        
 #endif
       }
       break;
-      
     case 'g':
-      if (folder->ff->st != NULL)
+      if (folder->f != NULL)
       {
-	if ((gr = getgrgid (folder->ff->st->st_gid)))
+	if ((gr = getgrgid (folder->f->st_gid)))
 	{
 	  snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
 	  snprintf (dest, destlen, tmp, gr->gr_name);
@@ -224,7 +220,7 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	else
 	{
 	  snprintf (tmp, sizeof (tmp), "%%%sld", fmt);
-	  snprintf (dest, destlen, tmp, folder->ff->st->st_gid);
+	  snprintf (dest, destlen, tmp, folder->f->st_gid);
 	}
       }
       else
@@ -233,12 +229,11 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	snprintf (dest, destlen, tmp, "");
       }
       break;
-      
     case 'l':
-      if (folder->ff->st != NULL)
+      if (folder->f != NULL)
       {
 	snprintf (tmp, sizeof (tmp), "%%%sd", fmt);
-	snprintf (dest, destlen, tmp, folder->ff->st->st_nlink);
+	snprintf (dest, destlen, tmp, folder->f->st_nlink);
       }
       else
       {
@@ -246,17 +241,15 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	snprintf (dest, destlen, tmp, "");
       }
       break;
-      
     case 'N':
       snprintf (tmp, sizeof (tmp), "%%%sc", fmt);
-      snprintf (dest, destlen, tmp, folder->ff->is_new ? 'N' : ' ');
+      snprintf (dest, destlen, tmp, folder->new ? 'N' : ' ');
       break;
-      
     case 's':
-      if (folder->ff->st != NULL)
+      if (folder->f != NULL)
       {
 	snprintf (tmp, sizeof (tmp), "%%%sld", fmt);
-	snprintf (dest, destlen, tmp, (long) folder->ff->st->st_size);
+	snprintf (dest, destlen, tmp, (long) folder->f->st_size);
       }
       else
       {
@@ -264,16 +257,10 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	snprintf (dest, destlen, tmp, "");
       }
       break;
-      
-    case 't':
-      snprintf (tmp, sizeof (tmp), "%%%sc", fmt);
-      snprintf (dest, destlen, tmp, folder->ff->tagged ? '*' : ' ');
-      break;
-      
     case 'u':
-      if (folder->ff->st != NULL)
+      if (folder->f != NULL)
       {
-	if ((pw = getpwuid (folder->ff->st->st_uid)))
+	if ((pw = getpwuid (folder->f->st_uid)))
 	{
 	  snprintf (tmp, sizeof (tmp), "%%%ss", fmt);
 	  snprintf (dest, destlen, tmp, pw->pw_name);
@@ -281,7 +268,7 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	else
 	{
 	  snprintf (tmp, sizeof (tmp), "%%%sld", fmt);
-	  snprintf (dest, destlen, tmp, folder->ff->st->st_uid);
+	  snprintf (dest, destlen, tmp, folder->f->st_uid);
 	}
       }
       else
@@ -290,11 +277,6 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 	snprintf (dest, destlen, tmp, "");
       }
       break;
-      
-    default:
-      snprintf (tmp, sizeof (tmp), "%%%sc", fmt);
-      snprintf (dest, destlen, tmp, op);
-      break;
   }
   return (src);
 }
@@ -302,6 +284,16 @@ folder_format_str (char *dest, size_t destlen, char op, const char *src,
 static void add_folder (MUTTMENU *m, struct browser_state *state,
 			const char *name, const struct stat *s, int new)
 {
+  char buffer[_POSIX_PATH_MAX + SHORT_STRING];
+  FOLDER folder;
+
+  folder.name = name;
+  folder.f = s;
+  folder.new = new;
+  mutt_FormatString (buffer, sizeof (buffer), NONULL(FolderFormat),
+		     folder_format_str, (unsigned long) &folder,
+		     M_FORMAT_ARROWCURSOR);
+
   if (state->entrylen == state->entrymax)
   {
     /* need to allocate more space */
@@ -313,20 +305,12 @@ static void add_folder (MUTTMENU *m, struct browser_state *state,
 
   if (s != NULL)
   {
-    (state->entry)[state->entrylen].mode = s->st_mode;
-    (state->entry)[state->entrylen].mtime = s->st_mtime;
-    (state->entry)[state->entrylen].size = s->st_size;
-    
-    (state->entry)[state->entrylen].st = safe_malloc (sizeof (struct stat));
-    memcpy ((state->entry)[state->entrylen].st, s, sizeof (struct stat));
+  (state->entry)[state->entrylen].mode = s->st_mode;
+  (state->entry)[state->entrylen].mtime = s->st_mtime;
+  (state->entry)[state->entrylen].size = s->st_size;
   }
-
-  (state->entry)[state->entrylen].is_new = new;
   (state->entry)[state->entrylen].name = safe_strdup (name);
-  (state->entry)[state->entrylen].desc = safe_strdup (name);
-#ifdef USE_IMAP
-  (state->entry)[state->entrylen].notfolder = 0;
-#endif
+  (state->entry)[state->entrylen].desc = safe_strdup (buffer);
 
   (state->entrylen)++;
 }
@@ -336,7 +320,6 @@ static void init_state (struct browser_state *state, MUTTMENU *menu)
   state->entrylen = 0;
   state->entrymax = 256;
   state->entry = (struct folder_file *) safe_malloc (sizeof (struct folder_file) * state->entrymax);
-  memset (state->entry, 0, sizeof (struct folder_file) * state->entrymax);
   if (menu)
     menu->data = state->entry;
 }
@@ -445,13 +428,7 @@ int select_file_search (MUTTMENU *menu, regex_t *re, int n)
 
 void folder_entry (char *s, size_t slen, MUTTMENU *menu, int num)
 {
-  FOLDER folder;
-
-  folder.ff = &((struct folder_file *) menu->data)[num];
-  folder.num = num;
-  
-  mutt_FormatString (s, slen, NONULL(FolderFormat), folder_format_str, 
-      (unsigned long) &folder, M_FORMAT_ARROWCURSOR);
+  snprintf (s, slen, "%2d %s", num + 1, ((struct folder_file *) menu->data)[num].desc);
 }
 
 static void init_menu (struct browser_state *state, MUTTMENU *menu, char *title,
@@ -474,32 +451,13 @@ static void init_menu (struct browser_state *state, MUTTMENU *menu, char *title,
   {
     strfcpy (path, LastDir, sizeof (path));
     mutt_pretty_mailbox (path);
-#ifdef USE_IMAP
-  if (state->imap_browse && option (OPTIMAPLSUB))
-    snprintf (title, titlelen, _("Subscribed [%s], File mask: %s"),
-	      path, NONULL (Mask.pattern));
-  else
-#endif
     snprintf (title, titlelen, _("Directory [%s], File mask: %s"),
-	      path, NONULL(Mask.pattern));
+	      path, NONULL (Mask.pattern));
   }
   menu->redraw = REDRAW_FULL;
 }
 
-int file_tag (MUTTMENU *menu, int n)
-{
-  struct folder_file *ff = &(((struct folder_file *)menu->data)[n]);
-  if (S_ISDIR (ff->mode) || (S_ISLNK (ff->mode) && link_is_dir (ff->name)))
-  {
-    mutt_error _("Can't attach a directory!");
-    return 0;
-  }
-  
-  return ((ff->tagged = !ff->tagged) ? 1 : -1);
-}
-
-void _mutt_select_file (char *f, size_t flen, int buffy,
-		       int multiple, char ***files, int *numfiles)
+void mutt_select_file (char *f, size_t flen, int buffy)
 {
   char buf[_POSIX_PATH_MAX];
   char prefix[_POSIX_PATH_MAX] = "";
@@ -515,17 +473,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
   if (*f)
   {
     mutt_expand_path (f, flen);
-#ifdef USE_IMAP
-    if (mx_is_imap (f))
-    {
-      init_state (&state, NULL);
-      state.imap_browse = 1;
-      imap_init_browse (f, &state);
-      strfcpy (LastDir, state.folder, sizeof (LastDir));
-    }
-    else
-    {
-#endif
     for (i = mutt_strlen (f) - 1; i > 0 && f[i] != '/' ; i--);
     if (i > 0)
     {
@@ -555,23 +502,9 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
     else
       strfcpy (prefix, f + i + 1, sizeof (prefix));
     killPrefix = 1;
-#ifdef USE_IMAP
-    }
-#endif
-  }
-  else 
-  {
-    if (!LastDir[0])
-      strfcpy (LastDir, NONULL(Maildir), sizeof (LastDir));
-#ifdef USE_IMAP
-    if (!buffy && mx_is_imap (LastDir))
-    {
-      init_state (&state, NULL);
-      state.imap_browse = 1;
-      imap_init_browse (LastDir, &state);
-    }
-#endif
   }
+  else if (!LastDir[0])
+    strfcpy (LastDir, NONULL(Maildir), sizeof (LastDir));
 
   *f = 0;
 
@@ -580,11 +513,14 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
     if (examine_mailboxes (NULL, &state) == -1)
       return;
   }
-  else
 #ifdef USE_IMAP
-  if (!state.imap_browse)
+  else if (mx_is_imap (LastDir))
+  {
+    mutt_error _("IMAP folder browsing is not currently supported");
+    return;
+  }
 #endif
-  if (examine_directory (NULL, &state, LastDir, prefix) == -1)
+  else if (examine_directory (NULL, &state, LastDir, prefix) == -1)
     return;
 
   menu = mutt_new_menu ();
@@ -593,8 +529,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
   menu->search = select_file_search;
   menu->title = title;
   menu->data = state.entry;
-  if (multiple)
-    menu->tag = file_tag;
 
   menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_FOLDER, FolderHelp);
 
@@ -614,11 +548,7 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 
         if (S_ISDIR (state.entry[menu->current].mode) ||
 	    (S_ISLNK (state.entry[menu->current].mode) &&
-	    link_is_dir (state.entry[menu->current].name)) 
-#ifdef USE_IMAP
-	    || state.entry[menu->current].notfolder
-#endif
-	    )
+	    link_is_dir (state.entry[menu->current].name)))
 	{
 	  /* make sure this isn't a MH or maildir mailbox */
 	  if (buffy)
@@ -626,21 +556,11 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	    strfcpy (buf, state.entry[menu->current].name, sizeof (buf));
 	    mutt_expand_path (buf, sizeof (buf));
 	  }
-#ifdef USE_IMAP
-	  else if (state.imap_browse)
-	  {
-            strfcpy (buf, state.entry[menu->current].name, sizeof (buf));
-	  }
-#endif
 	  else
 	    snprintf (buf, sizeof (buf), "%s/%s", LastDir, 
 		      state.entry[menu->current].name);
 
-	  if ((mx_get_magic (buf) <= 0)
-#ifdef USE_IMAP
-	    || state.entry[menu->current].notfolder
-#endif
-	    )
+	  if (mx_get_magic (buf) <= 0)
 	  {
 	    char OldLastDir[_POSIX_PATH_MAX];
 
@@ -671,13 +591,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	      sprintf (LastDir, "%s", state.entry[menu->current].name);
 	      mutt_expand_path (LastDir, sizeof (LastDir));
 	    }
-#ifdef USE_IMAP
-	    else if (state.imap_browse)
-	    {
-              strfcpy (LastDir, state.entry[menu->current].name,
-                sizeof (LastDir));
-	    }
-#endif
 	    else
 	      sprintf (LastDir + mutt_strlen (LastDir), "/%s",
 		       state.entry[menu->current].name);
@@ -689,16 +602,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	      killPrefix = 0;
 	    }
 	    buffy = 0;
-#ifdef USE_IMAP
-	    if (state.imap_browse)
-	    {
-	      init_state (&state, NULL);
-	      state.imap_browse = 1;
-	      imap_init_browse (LastDir, &state);
-	      menu->data = state.entry;
-	    }
-	    else
-#endif
 	    if (examine_directory (menu, &state, LastDir, prefix) == -1)
 	    {
 	      /* try to restore the old values */
@@ -721,10 +624,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	  strfcpy (f, state.entry[menu->current].name, flen);
 	  mutt_expand_path (f, flen);
 	}
-#ifdef USE_IMAP
-	else if (state.imap_browse)
-          strfcpy (f, state.entry[menu->current].name, flen);
-#endif
 	else
 	  snprintf (f, flen, "%s/%s", LastDir, state.entry[menu->current].name);
 
@@ -732,38 +631,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 
       case OP_EXIT:
 
-	if (multiple)
-	{
-	  char **tfiles;
-	  int i, j;
-
-	  if (menu->tagged)
-	  {
-	    *numfiles = menu->tagged;
-	    tfiles = safe_malloc (*numfiles * sizeof (char *));
-	    for (i = 0, j = 0; i < state.entrylen; i++)
-	    {
-	      struct folder_file ff = state.entry[i];
-	      char full[_POSIX_PATH_MAX];
-	      if (ff.tagged)
-	      {
-		snprintf (full, sizeof (full), "%s/%s", LastDir, ff.name);
-		mutt_expand_path (full, sizeof (full));
-		tfiles[j++] = safe_strdup (full);
-	      }
-	    }
-	    *files = tfiles;
-	  }
-	  else if (f[0]) /* no tagged entries. return selected entry */
-	  {
-	    *numfiles = 1;
-	    tfiles = safe_malloc (*numfiles * sizeof (char *));
-	    mutt_expand_path (f, flen);
-	    tfiles[0] = safe_strdup (f);
-	    *files = tfiles;
-	  }
-	}
-
 	destroy_state (&state);
 	mutt_menuDestroy (&menu);
 	return;
@@ -772,35 +639,10 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
         if(state.entrylen)
 	  mutt_message(state.entry[menu->current].name);
         break;
-
-#ifdef USE_IMAP
-      case OP_BROWSER_SUBSCRIBE:
-	imap_subscribe (state.entry[menu->current].name, 1);
-	break;
-
-      case OP_BROWSER_UNSUBSCRIBE:
-	imap_subscribe (state.entry[menu->current].name, 0);
-	break;
-
-      case OP_BROWSER_TOGGLE_LSUB:
-	if (option (OPTIMAPLSUB))
-	{
-	  unset_option (OPTIMAPLSUB);
-	}
-	else
-	{
-	  set_option (OPTIMAPLSUB);
-	}
-	mutt_ungetch (0, OP_CHECK_NEW);
-	break;
-#endif
       
       case OP_CHANGE_DIRECTORY:
 
 	strfcpy (buf, LastDir, sizeof (buf));
-#ifdef USE_IMAP
-	if (!state.imap_browse)
-#endif
 	{/* add '/' at the end of the directory name */
 	int len=mutt_strlen(LastDir);
 	if (sizeof (buf) > len)
@@ -812,21 +654,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	{
 	  buffy = 0;	  
 	  mutt_expand_path (buf, sizeof (buf));
-#ifdef USE_IMAP
-	  if (mx_is_imap (buf))
-	  {
-	    strfcpy (LastDir, buf, sizeof (LastDir));
-	    destroy_state (&state);
-	    init_state (&state, NULL);
-	    state.imap_browse = 1;
-	    imap_init_browse (LastDir, &state);
-	    menu->data = state.entry;
-	    menu->current = 0; 
-	    menu->top = 0; 
-	    init_menu (&state, menu, title, sizeof (title), buffy);
-	  }
-	  else
-#endif
 	  if (stat (buf, &st) == 0)
 	  {
 	    if (S_ISDIR (st.st_mode))
@@ -894,17 +721,6 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	    Mask.not = not;
 
 	    destroy_state (&state);
-#ifdef USE_IMAP
-	    if (state.imap_browse)
-	    {
-	      init_state (&state, NULL);
-	      state.imap_browse = 1;
-	      imap_init_browse (LastDir, &state);
-	      menu->data = state.entry;
-	      init_menu (&state, menu, title, sizeof (title), buffy);
-	    }
-	    else
-#endif
 	    if (examine_directory (menu, &state, LastDir, NULL) == 0)
 	      init_menu (&state, menu, title, sizeof (title), buffy);
 	    else
@@ -973,21 +789,11 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	destroy_state (&state);
 	prefix[0] = 0;
 	killPrefix = 0;
-
 	if (buffy)
 	{
 	  if (examine_mailboxes (menu, &state) == -1)
 	    return;
 	}
-#ifdef USE_IMAP
-	else if (mx_is_imap (LastDir))
-	{
-	  init_state (&state, NULL);
-	  state.imap_browse = 1;
-	  imap_init_browse (LastDir, &state);
-	  menu->data = state.entry;
-	}
-#endif
 	else if (examine_directory (menu, &state, LastDir, prefix) == -1)
 	  return;
 	init_menu (&state, menu, title, sizeof (title), buffy);
