@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -26,10 +26,6 @@
 #include "mx.h"
 #include "pager.h"
 
-#ifdef USE_IMAP
-#include "imap.h"
-#endif
-
 #ifdef BUFFY_SIZE
 #include "buffy.h"
 #endif
@@ -75,6 +71,13 @@ int mutt_display_message (HEADER *cur)
 
 
 
+
+
+
+
+
+
+
   mutt_mktemp (tempfile);
   if ((fpout = safe_fopen (tempfile, "w")) == NULL)
   {
@@ -106,12 +109,10 @@ int mutt_display_message (HEADER *cur)
     return (0);
   }
 
-
   if (builtin)
   {
     pager_t info;
-
-
+    
     /* Invoke the builtin pager */
     memset (&info, 0, sizeof (pager_t));
     info.hdr = cur;
@@ -193,26 +194,11 @@ void ci_bounce_message (HEADER *h, int *redraw)
 
 void mutt_pipe_message_to_state (HEADER *h, STATE *s)
 {
-  int cmflags = 0;
-  int chflags = CH_FROM;
-  
-  if (option (OPTPIPEDECODE))
-  {
-    cmflags |= M_CM_DECODE | M_CM_CHARCONV;
-    chflags |= CH_DECODE | CH_REORDER;
-    
-    if (option (OPTWEED))
-    {
-      chflags |= CH_WEED;
-      cmflags |= M_CM_WEED;
-    }
-  }
-  
   if (option (OPTPIPEDECODE))
     mutt_parse_mime_message (Context, h);
-
   mutt_copy_message (s->fpout, Context, h,
-		     cmflags, chflags);
+		     option (OPTPIPEDECODE) ? M_CM_DECODE | M_CM_CHARCONV: 0,
+		     option (OPTPIPEDECODE) ? CH_FROM | CH_WEED | CH_DECODE | CH_REORDER : CH_FROM);
 }
 
 int mutt_pipe_message (HEADER *h)
@@ -402,64 +388,47 @@ void mutt_enter_command (void)
     set_option (OPTNEEDRESORT);
 }
 
-void mutt_display_address (ENVELOPE *env)
+void mutt_display_address (ADDRESS *adr)
 {
-  char *pfx = NULL;
   char buf[SHORT_STRING];
-  ADDRESS *adr = NULL;
-
-  adr = mutt_get_address (env, &pfx);
-
-  if (!adr) return;
 
   buf[0] = 0;
   rfc822_write_address (buf, sizeof (buf), adr);
-  mutt_message ("%s: %s", pfx, buf);
+  mutt_message ("%s", buf);
 }
 
-static void set_copy_flags (HEADER *hdr, int decode, int decrypt, int *cmflags, int *chflags)
+static void set_copy_flags(HEADER *hdr, int decode, int decrypt, int *cmflags, int *chflags)
 {
   *cmflags = 0;
   *chflags = CH_UPDATE_LEN;
   
 
-  if (decode)
+  if(decode)
   {
     *chflags = CH_XMIT | CH_MIME | CH_TXTPLAIN;
     *cmflags = M_CM_DECODE | M_CM_CHARCONV;
   }
 
-  /* respect $weed only if decode doesn't kick in
-   * for decrypt.
-   */
-
-  if (decode && !decrypt && option (OPTWEED))
-  {
-    *chflags |= CH_WEED;
-    *cmflags |= M_CM_WEED;
-  }
 }
 
 static void _mutt_save_message (HEADER *h, CONTEXT *ctx, int delete, int decode, int decrypt)
 {
   int cmflags, chflags;
   
-  set_copy_flags (h, decode, decrypt, &cmflags, &chflags);
+  set_copy_flags(h, decode, decrypt, &cmflags, &chflags);
 
-  if (decode || decrypt)
+  if (decode  || decrypt)
     mutt_parse_mime_message (Context, h);
 
   if (mutt_append_message (ctx, Context, h, cmflags, chflags) == 0 && delete)
   {
     mutt_set_flag (Context, h, M_DELETE, 1);
-    if (option (OPTDELETEUNTAG))
-      mutt_set_flag (Context, h, M_TAG, 0);
+    mutt_set_flag (Context, h, M_TAG, 0);
   }
 }
 
 /* returns 0 if the copy/save was successful, or -1 on error/abort */
-int mutt_save_message (HEADER *h, int delete, 
-		       int decode, int decrypt, int *redraw)
+int mutt_save_message (HEADER *h, int delete, int decode, int decrypt, int *redraw)
 {
   int i, need_buffy_cleanup;
   char prompt[SHORT_STRING], buf[_POSIX_PATH_MAX];
@@ -537,22 +506,6 @@ int mutt_save_message (HEADER *h, int delete,
   
   mutt_message (_("Copying to %s..."), buf);
   
-#ifdef USE_IMAP
-  if (Context->magic == M_IMAP && 
-      !(decode || decrypt) && mx_is_imap (buf))
-  {
-    switch (imap_copy_messages (Context, h, buf, delete))
-    {
-      /* success */
-      case 0: mutt_clear_error (); return 0;
-      /* non-fatal error: fall through to fetch/append */
-      case 1: break;
-      /* fatal error, abort */
-      case -1: return -1;
-    }
-  }
-#endif
-
   if (mx_open_mailbox (buf, M_APPEND, &ctx) != NULL)
   {
     if (h)
@@ -598,18 +551,14 @@ int mutt_save_message (HEADER *h, int delete,
 
 static void print_msg (FILE *fp, CONTEXT *ctx, HEADER *h)
 {
-  int cmflags = M_CM_DECODE | M_CM_CHARCONV;
-  int chflags = CH_DECODE | CH_REORDER;
+  
+
+
 
-  if (option (OPTWEED))
-  {
-    cmflags |= M_CM_WEED;
-    chflags |= CH_WEED;
-  }
 
 
   mutt_parse_mime_message (ctx, h);
-  mutt_copy_message (fp, ctx, h, cmflags, chflags);
+  mutt_copy_message (fp, ctx, h, M_CM_DECODE | M_CM_CHARCONV, CH_WEED | CH_DECODE | CH_REORDER);
 }
 
 void mutt_print_message (HEADER *h)
