@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ struct binding_t OpMain[] = {
   { "previous-new",		OP_MAIN_PREV_NEW,		"\033\t" },
   { "next-unread",		OP_MAIN_NEXT_UNREAD,		NULL },
   { "previous-unread",		OP_MAIN_PREV_UNREAD,		NULL },
-  { "parent-message",		OP_MAIN_PARENT_MESSAGE,		"P" },
+
 
 
 
@@ -203,7 +203,7 @@ struct binding_t OpPager[] = {
   { "half-up",		OP_HALF_UP,			NULL },
   { "half-down",	OP_HALF_DOWN,			NULL },
   { "previous-line",	OP_PREV_LINE,			NULL },
-  { "parent-message",	OP_MAIN_PARENT_MESSAGE,		"P" },
+
 
 
 
@@ -242,7 +242,6 @@ struct binding_t OpAttach[] = {
 struct binding_t OpCompose[] = {
   { "attach-file",	OP_COMPOSE_ATTACH_FILE,		"a" },
   { "attach-message",	OP_COMPOSE_ATTACH_MESSAGE,	"A" },
-  { "change-charset",	OP_COMPOSE_CHANGE_CHARSET,	NULL },
   { "edit-bcc",		OP_COMPOSE_EDIT_BCC,		"b" },
   { "edit-cc",		OP_COMPOSE_EDIT_CC,		"c" },
   { "copy-file",	OP_SAVE,			"C" },
@@ -268,16 +267,13 @@ struct binding_t OpCompose[] = {
   { "edit-to",		OP_COMPOSE_EDIT_TO,		"t" },
   { "edit-type",	OP_COMPOSE_EDIT_TYPE,		"\024" },
   { "write-fcc",	OP_COMPOSE_WRITE_MESSAGE,	"w" },
-  { "recode-attachment",OP_COMPOSE_RECODE,		NULL },
   { "toggle-unlink",	OP_COMPOSE_TOGGLE_UNLINK,	"u" },
-  { "toggle-recode",    OP_COMPOSE_TOGGLE_RECODE,	NULL },
   { "update-encoding",	OP_COMPOSE_UPDATE_ENCODING,	"U" },
   { "view-attach",	OP_VIEW_ATTACH,			M_ENTER_S },
   { "send-message",	OP_COMPOSE_SEND_MESSAGE,	"y" },
   { "pipe-entry",	OP_PIPE,			"|" },
 
 
-  
   { NULL,		0,				NULL }
 };
 
@@ -298,11 +294,6 @@ struct binding_t OpBrowser[] = {
   { "check-new",	OP_CHECK_NEW,		NULL },
   { "toggle-mailboxes", OP_TOGGLE_MAILBOXES, 	"\t" },
   { "view-file",	OP_BROWSER_VIEW_FILE,	" " },
-#ifdef USE_IMAP
-  { "subscribe",	OP_BROWSER_SUBSCRIBE,	"s" },
-  { "unsubscribe",	OP_BROWSER_UNSUBSCRIBE,	"u" },
-  { "toggle-subscribed", OP_BROWSER_TOGGLE_LSUB, "T" },
-#endif
   { NULL,		0,			NULL }
 };
 
@@ -336,5 +327,3 @@ struct binding_t OpEditor[] = {
 
 
 
-
-
