@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -22,12 +22,6 @@ WHERE CONTEXT *Context;
 
 WHERE char Errorbuf[SHORT_STRING];
 
-#if defined(DL_STANDALONE) && defined(USE_DOTLOCK)
-WHERE char *MuttDotlock;
-#endif
-
-WHERE ADDRESS *From;
-
 WHERE char *AliasFile;
 WHERE char *AliasFmt;
 WHERE char *AttachSep;
@@ -48,10 +42,8 @@ WHERE char *Homedir;
 WHERE char *Hostname;
 #ifdef USE_IMAP
 WHERE char *ImapUser INITVAL (NULL);
-WHERE char *ImapCRAMKey INITVAL (NULL);
 WHERE char *ImapPass INITVAL (NULL);
-WHERE short ImapCheckTimeout;
-WHERE char *ImapHomeNamespace INITVAL (NULL);
+WHERE short ImapCheckTime;
 #endif
 WHERE char *InReplyTo;
 WHERE char *Inbox;
@@ -60,8 +52,6 @@ WHERE char *Locale;
 WHERE char *MailcapPath;
 WHERE char *Maildir;
 WHERE char *MsgFmt;
-
-
 WHERE char *Muttrc INITVAL (NULL);
 WHERE char *Outbox;
 WHERE char *Pager;
@@ -78,7 +68,6 @@ WHERE char *Prefix;
 WHERE char *PrintCmd;
 WHERE char *QueryCmd;
 WHERE char *Realname;
-WHERE char *SendCharset;
 WHERE char *Sendmail;
 WHERE char *Shell;
 WHERE char *Signature;
@@ -99,7 +88,6 @@ WHERE LIST *HeaderOrderList INITVAL(0);
 WHERE LIST *Ignore INITVAL(0);
 WHERE LIST *UnIgnore INITVAL(0);
 WHERE LIST *MailLists INITVAL(0);
-WHERE LIST *SubscribedLists INITVAL(0);
 
 /* bit vector for boolean variables */
 #ifdef MAIN_C
@@ -109,11 +97,7 @@ extern unsigned char Options[];
 #endif
 
 /* bit vector for the yes/no/ask variable type */
-#ifdef MAIN_C
-unsigned char QuadOptions[(OPT_MAX*2 + 7) / 8];
-#else
-extern unsigned char QuadOptions[];
-#endif
+WHERE unsigned long QuadOptions INITVAL (0);
 
 WHERE unsigned short Counter INITVAL (0);
 
