@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1996-9 Brandon Long <blong@fiction.net>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Brandon Long <blong@fiction.net>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -1966,7 +1966,8 @@ void imap_fastclose_mailbox (CONTEXT *ctx)
     return;
 
   if ((CTX_DATA->state == IMAP_SELECTED) && (ctx == CTX_DATA->selected_ctx))
-    if (imap_close_mailbox (CTX_DATA) != 0)
+    if (!imap_close_mailbox (CTX_DATA))
+      return;
 
   for (i = 0; i < IMAP_CACHE_LEN; i++)
   {
@@ -2071,9 +2072,9 @@ int imap_buffy_check (char *path)
    * command on a mailbox that you have selected 
    */
 
-  if (mutt_strcmp(mbox, idata->selected_mailbox) == 0
-      || (mutt_strcasecmp(mbox, "INBOX") == 0
-	  && mutt_strcasecmp(mbox, idata->selected_mailbox) == 0))
+  if (mutt_strcmp(mbox_unquoted, idata->selected_mailbox) == 0
+      || (mutt_strcasecmp(mbox_unquoted, "INBOX") == 0
+	  && mutt_strcasecmp(mbox_unquoted, idata->selected_mailbox) == 0))
   {
     snprintf (buf, sizeof (buf), "%s NOOP\r\n", seq);
   }
