@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -40,29 +40,17 @@
 #include <errno.h>
 #include <sys/wait.h>
 
-void toggle_quadoption (int opt)
-{
-  int n = opt/4;
-  int b = (opt % 4) * 2;
-
-  QuadOptions[n] ^= (1 << b);
-}
+#define toggle_quadoption(opt) QuadOptions ^= (1 << (2 * opt))
 
 void set_quadoption (int opt, int flag)
 {
-  int n = opt/4;
-  int b = (opt % 4) * 2;
-
-  QuadOptions[n] &= ~(0x3 << b);
-  QuadOptions[n] |= (flag & 0x3) << b;
+  QuadOptions &= ~(0x3 << (2 * opt)); /* first clear the bits */
+  QuadOptions |= (flag & 0x3) << (2 * opt); /* now set them */
 }
 
 int quadoption (int opt)
 {
-  int n = opt/4;
-  int b = (opt % 4) * 2;
-
-  return (QuadOptions[n] >> b) & 0x3;
+  return ((QuadOptions >> (opt * 2)) & 0x3);
 }
 
 int query_quadoption (int opt, const char *prompt)
@@ -295,6 +283,7 @@ int mutt_extract_token (BUFFER *dest, BUFFER *tok, int flags)
   return 0;
 }
 
+
 static void add_to_list (LIST **list, const char *str)
 {
   LIST *t, *last = NULL;
@@ -356,12 +345,17 @@ static void remove_from_list (LIST **l, const char *str)
   }
 }
 
+
 static int parse_unignore (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
   do
   {
     mutt_extract_token (buf, s, 0);
-    add_to_list (&UnIgnore, buf->data);
+
+    /* don't add "*" to the unignore list */
+    if (strcmp (buf->data, "*")) 
+      add_to_list (&UnIgnore, buf->data);
+
     remove_from_list (&Ignore, buf->data);
   }
   while (MoreArgs (s));
@@ -382,6 +376,7 @@ static int parse_ignore (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err
   return 0;
 }
 
+
 static int parse_list (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
   do
@@ -406,33 +401,6 @@ static int parse_unlist (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err
   return 0;
 }
 
-
-static int parse_unlists (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
-{
-  do
-  {
-    mutt_extract_token (buf, s, 0);
-    remove_from_list (&MailLists, buf->data);
-    remove_from_list (&SubscribedLists, buf->data);
-  }
-  while (MoreArgs (s));
-
-  return 0;
-}
-
-static int parse_subscribe (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
-{
-  do
-  {
-    mutt_extract_token (buf, s, 0);
-    add_to_list (&MailLists, buf->data);
-    add_to_list (&SubscribedLists, buf->data);
-  }
-  while (MoreArgs (s));
-
-  return 0;
-}
-  
 static int parse_unalias (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 {
   ALIAS *tmp, *last = NULL;
@@ -655,13 +623,6 @@ static void mutt_restore_default (struct option_t *p)
 	*((char **) p->data) = safe_strdup (path);
       }
       break;
-    case DT_ADDR:
-      if (p->init)
-      {
-	rfc822_free_address ((ADDRESS **) p->data);
-	*((ADDRESS **) p->data) = rfc822_parse_adrlist (NULL, (char *) p->init);
-      }
-      break;
     case DT_BOOL:
       if (p->init)
 	set_option (p->data);
@@ -830,51 +791,30 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 	set_option (MuttVars[idx].data);
     }
     else if (DTYPE (MuttVars[idx].type) == DT_STR ||
-	     DTYPE (MuttVars[idx].type) == DT_PATH ||
-	     DTYPE (MuttVars[idx].type) == DT_ADDR)
+	     DTYPE (MuttVars[idx].type) == DT_PATH)
     {
       if (query || *s->dptr != '=')
       {
-	char _tmp[STRING];
-	char *val = NULL;
-	
-	if (DTYPE (MuttVars[idx].type) == DT_ADDR)
-	{
-	  _tmp[0] = '\0';
-	  rfc822_write_address (_tmp, sizeof (_tmp), *((ADDRESS **) MuttVars[idx].data));
-	  val = _tmp;
-	}
-	else
-	  val = *((char **) MuttVars[idx].data);
-	
 	/* user requested the value of this variable */
 	snprintf (err->data, err->dsize, "%s=\"%s\"", MuttVars[idx].option,
-		  NONULL (val));
+		  NONULL (*((char **) MuttVars[idx].data)));
 	break;
       }
 
       s->dptr++;
 
       /* copy the value of the string */
-      if (DTYPE (MuttVars[idx].type) == DT_ADDR)
-	rfc822_free_address ((ADDRESS **) MuttVars[idx].data);
-      else
-	FREE (MuttVars[idx].data);
-
+      FREE (MuttVars[idx].data);
       mutt_extract_token (tmp, s, 0);
-      if (DTYPE (MuttVars[idx].type) == DT_PATH)
+      if (MuttVars[idx].type == DT_PATH)
       {
 	strfcpy (scratch, tmp->data, sizeof (scratch));
 	mutt_expand_path (scratch, sizeof (scratch));
 	*((char **) MuttVars[idx].data) = safe_strdup (scratch);
       }
-      else if (DTYPE (MuttVars[idx].type) == DT_STR)
-      {
-	*((char **) MuttVars[idx].data) = safe_strdup (tmp->data);
-      }
       else
       {
-	*((ADDRESS **) MuttVars[idx].data) = rfc822_parse_adrlist (NULL, tmp->data);
+	*((char **) MuttVars[idx].data) = safe_strdup (tmp->data);
       }
     }
     else if (DTYPE(MuttVars[idx].type) == DT_RX)
@@ -1139,6 +1079,16 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
   return (r);
 }
 
+void mutt_nocurses_error (const char *fmt, ...)
+{
+  va_list ap;
+
+  va_start (ap, fmt);
+  vfprintf (stderr, fmt, ap);
+  va_end (ap);
+  fputc ('\n', stderr);
+}
+
 /* reads the specified initialization file.  returns -1 if errors were found
    so that we can pause to let the user know...  */
 static int source_rc (const char *rcfile, BUFFER *err)
@@ -1464,29 +1414,20 @@ int mutt_var_value_complete (char *buffer, size_t len, int pos)
       return 0; /* no such variable. */
     else
     {
-      char tmp [LONG_STRING], tmp2[LONG_STRING];
-      char *s, *d;
+      char tmp [LONG_STRING];
       size_t dlen = buffer + len - pt - spaces;
       char *vals[] = { "no", "yes", "ask-no", "ask-yes" };
-
-      tmp[0] = '\0';
-
+      strfcpy (tmp, pt, sizeof(tmp));
+      
       if ((DTYPE(MuttVars[idx].type) == DT_STR) || 
 	  (DTYPE(MuttVars[idx].type) == DT_PATH) ||
 	  (DTYPE(MuttVars[idx].type) == DT_RX))
-      {
-	strfcpy (tmp, NONULL (*((char **) MuttVars[idx].data)), sizeof (tmp));
-	if (DTYPE (MuttVars[idx].type) == DT_PATH)
-	  mutt_pretty_mailbox (tmp);
-      }
-      else if (DTYPE (MuttVars[idx].type) == DT_ADDR)
-      {
-	rfc822_write_address (tmp, sizeof (tmp), *((ADDRESS **) MuttVars[idx].data));
-      }
+	snprintf(pt, dlen, "%s\"%s\"", tmp, 
+		  NONULL (*((char **) MuttVars[idx].data)));
       else if (DTYPE (MuttVars[idx].type) == DT_QUAD)
-	strfcpy (tmp, vals[quadoption (MuttVars[idx].data)], sizeof (tmp));
+	snprintf(pt, dlen, "%s%s", tmp,  vals[quadoption (MuttVars[idx].data)]);
       else if (DTYPE (MuttVars[idx].type) == DT_NUM)
-	snprintf (tmp, sizeof (tmp), "%d", (*((short *) MuttVars[idx].data)));
+	snprintf (pt, dlen, "%s%d", tmp, (*((short *) MuttVars[idx].data)));
       else if (DTYPE (MuttVars[idx].type) == DT_SORT)
       {
 	const struct mapping_t *map;
@@ -1505,27 +1446,16 @@ int mutt_var_value_complete (char *buffer, size_t len, int pos)
 	    break;
 	}
 	p = mutt_getnamebyvalue (*((short *) MuttVars[idx].data) & SORT_MASK, map);
-	snprintf (tmp, sizeof (tmp), "%s%s%s",
+	snprintf (pt, dlen, "%s\"%s%s%s\"", tmp,
 		  (*((short *) MuttVars[idx].data) & SORT_REVERSE) ? "reverse-" : "",
 		  (*((short *) MuttVars[idx].data) & SORT_LAST) ? "last-" : "",
 		  p);
       }
       else if (DTYPE (MuttVars[idx].type) == DT_BOOL)
-	strfcpy (tmp, option (MuttVars[idx].data) ? "yes" : "no", sizeof (tmp));
+	snprintf (pt, dlen, "%s%s", tmp, 
+		  option (MuttVars[idx].data) ? "yes" : "no");
       else
 	return 0;
-      
-      for (s = tmp, d = tmp2; *s && (d - tmp2) < sizeof (tmp2) - 2;)
-      {
-	if (*s == '\\' || *s == '"')
-	  *d++ = '\\';
-	*d++ = *s++;
-      }
-      *d = '\0';
-      
-      strfcpy (tmp, pt, sizeof (tmp));
-      snprintf (pt, dlen, "%s\"%s\"", tmp, tmp2);
-	  
       return 1;
     }
   }
@@ -1701,6 +1631,11 @@ void mutt_init (int skip_sys_rc, LIST *commands)
 
   Tempdir = safe_strdup ((p = getenv ("TMPDIR")) ? p : "/tmp");
 
+  
+
+  
+  
+
 #ifdef USE_POP
   PopUser = safe_strdup (Username);
 #endif
@@ -1813,7 +1748,5 @@ void mutt_init (int skip_sys_rc, LIST *commands)
       mutt_exit(1);
   }
 
-#if 0
   set_option (OPTWEED); /* turn weeding on by default */
-#endif
 }
