@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -23,10 +23,6 @@
 #include "mime.h"
 #include "mailbox.h"
 #include "mapping.h"
-#ifdef USE_IMAP
-#include "mx.h"
-#include "imap.h"
-#endif
 
 #include <ctype.h>
 #include <unistd.h>
@@ -55,28 +51,13 @@ int mutt_num_postponed (void)
   struct stat st;
   CONTEXT ctx;
 
-#ifdef USE_IMAP
-  /* LastModify is useless for IMAP */
-  if (Postponed && mx_is_imap (Postponed))
-  {
-    PostCount = imap_mailbox_check (Postponed, 0);
-    PostCount = (PostCount < 0) ? 0 : PostCount;
-    dprint(2, (debugfile,
-      "mutt_num_postponed: %d postponed IMAP messages found.\n", PostCount));
-
-    return PostCount;
-  }
-#endif
-
   if (!Postponed || stat (Postponed, &st) == -1)
   {
      PostCount = 0;
      LastModify = 0;
      return (0);
   } 
-
-
-  if (S_ISDIR (st.st_mode))
+  else if (S_ISDIR (st.st_mode))
   {
     /* if we have a maildir mailbox, we need to stat the "new" dir */
 
@@ -191,28 +172,10 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
   LIST *next;
   char *p;
   int opt_delete;
-#ifdef USE_IMAP
-  char curpath[LONG_STRING];
-  int need_reopen = 0;
-#endif
 
   if (!Postponed)
     return (-1);
 
-#ifdef USE_IMAP
-  /* if we're in an IMAP folder and the postponed folder is also IMAP, we may
-   * need to take steps to avoid opening an additional connection to the same
-   * server. */
-  if ((ctx && ctx->magic == M_IMAP) && mx_is_imap (Postponed))
-  { 
-    strfcpy (curpath, ctx->path, sizeof (curpath));
-    if (imap_select_mailbox (ctx, Postponed) < 0)
-      return -1;
-    need_reopen = 1;
-    PostContext = ctx;
-  }
-  else
-#endif
   if ((PostContext = mx_open_mailbox (Postponed, M_NOSORT, NULL)) == NULL)
   {
     PostCount = 0;
@@ -224,11 +187,6 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
   {
     PostCount = 0;
     mx_close_mailbox (PostContext);
-#ifdef USE_IMAP
-  if (need_reopen)
-    ctx = mx_open_mailbox (curpath, 0, PostContext);
-  else
-#endif
     safe_free ((void **) &PostContext);
     mutt_error _("No postponed messages.");
     return (-1);
@@ -242,25 +200,15 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
   else if ((h = select_msg ()) == NULL)
   {
     mx_close_mailbox (PostContext);
-#ifdef USE_IMAP
-  if (need_reopen)
-    ctx = mx_open_mailbox (curpath, 0, PostContext);
-  else
-#endif
     safe_free ((void **) &PostContext);
     return (-1);
   }
 
   if (mutt_prepare_edit_message (PostContext, hdr, h) < 0)
   {
-    mx_fastclose_mailbox (PostContext);
-#ifdef USE_IMAP
-    if (need_reopen)
-      ctx = mx_open_mailbox (curpath, 0, NULL);
-    else
-#endif
-    safe_free ((void **) &PostContext);
-    return (-1);
+      mx_fastclose_mailbox (PostContext);
+      safe_free ((void **) &PostContext);
+      return (-1);
   }
 
   /* finished with this message, so delete it. */
@@ -275,11 +223,6 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
   mx_close_mailbox (PostContext);
   set_quadoption (OPT_DELETE, opt_delete);
 
-#ifdef USE_IMAP
-  if (need_reopen)
-    ctx = mx_open_mailbox (curpath, 0, PostContext);
-  else
-#endif
   safe_free ((void **) &PostContext);
 
   for (tmp = hdr->env->userhdrs; tmp; )
@@ -329,6 +272,7 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
 
 
 
+
     else
     {
       last = tmp;
@@ -345,7 +289,6 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size
 
 int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
 {
-  PARAMETER *par;
   MESSAGE *msg = mx_open_message (ctx, hdr->msgno);
   char file[_POSIX_PATH_MAX];
 
@@ -354,7 +297,8 @@ int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
 
   fseek (msg->fp, hdr->offset, 0);
   newhdr->env = mutt_read_rfc822_header (msg->fp, newhdr, 1);
-
+  mutt_free_body (&newhdr->content);
+  
   if (hdr->content->type == TYPEMESSAGE || hdr->content->type == TYPEMULTIPART)
   {
     BODY *b;
@@ -365,7 +309,8 @@ int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
      * message.
      */
     newhdr->content = hdr->content->parts;
-    for (b = hdr->content->parts; b; b = b->next)
+    b = hdr->content->parts;
+    while (b != NULL)
     {
       file[0] = '\0';
       if (b->filename)
@@ -384,24 +329,15 @@ int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
       safe_free ((void *) &b->filename);
       b->filename = safe_strdup (file);
       b->unlink = 1;
-
-      if (mutt_is_text_type (b->type, b->subtype))
-	b->noconv = 1;
-      
       mutt_stamp_attachment (b);
       mutt_free_body (&b->parts);
+      b = b->next;
     }
     hdr->content->parts = NULL;
-    if (hdr->content->type == TYPEMESSAGE && hdr->content->hdr)
-      hdr->content->hdr->content = NULL;
   }
   else
   {
-    BODY *b = hdr->content;
-    file[0] = 0;
-    if (b->filename)
-      strfcpy (file, b->filename, sizeof (file));
-    mutt_adv_mktemp (file, sizeof(file));
+    mutt_mktemp (file);
     if (mutt_save_attachment (msg->fp, hdr->content, file, 0, NULL) == -1)
     {
       mutt_free_envelope (&newhdr->env);
@@ -412,18 +348,10 @@ int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
     
     FREE (&newhdr->content->subtype);
     FREE (&newhdr->content->xtype);
-    FREE (&newhdr->content->description);
     
     newhdr->content->type = hdr->content->type;
     newhdr->content->xtype = safe_strdup (hdr->content->xtype);
     newhdr->content->subtype = safe_strdup (hdr->content->subtype);
-    newhdr->content->description = safe_strdup (hdr->content->description);
-
-    for (par = hdr->content->parameter; par; par = par->next)
-      mutt_set_parameter (par->attribute, par->value, &newhdr->content->parameter);
-
-    if (mutt_is_text_type (newhdr->content->type, newhdr->content->subtype))
-      newhdr->content->noconv = 1;
     
     newhdr->content->use_disp = 0;	/* no content-disposition */
     newhdr->content->unlink = 1;	/* delete when we are done */
